Checking Available Hardware
===========================

.. currentmodule:: sounddevice

.. autosummary::
   :nosignatures:

   query_devices
   DeviceList
   query_hostapis
   check_input_settings
   check_output_settings

.. autofunction:: query_devices

.. autoclass:: DeviceList

.. autofunction:: query_hostapis

.. autofunction:: check_input_settings

.. autofunction:: check_output_settings
